==> cloud-8.x-1.1.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Ec2/InstanceStartMultipleForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\cloud\Entity\CloudContentEntityBase;

/**
 * Provides an entities start confirmation form.
 */
class InstanceStartMultipleForm extends AwsCloudProcessMultipleForm {

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {

    return $this->formatPlural(count($this->selection),
      'Are you sure you want to start this @item?',
      'Are you sure you want to start these @items?', [
        '@item' => $this->entityType->getSingularLabel(),
        '@items' => $this->entityType->getPluralLabel(),
      ]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {

    return $this->t('Start');
  }

  /**
   * {@inheritdoc}
   */
  protected function processAwsResource(CloudContentEntityBase $entity) {

    $this->awsEc2Service->setCloudContext($entity->getCloudContext());

    return $this->awsEc2Service->startInstances([
      'InstanceIds' => [$entity->getInstanceId()],
    ]);
  }

  /**
   * {@inheritdoc}
   */
  protected function processEntity(CloudContentEntityBase $entity) {}

  /**
   * Process an entity and related AWS resource.
   *
   * @param \Drupal\cloud\Entity\CloudContentEntityBase $entity
   *   An entity object.
   *
   * @return bool
   *   Succeeded or failed.
   */
  protected function process(CloudContentEntityBase $entity) {

    if ($this->processAwsResource($entity)) {
      $message = $this->t('The @type "@label" has been started.', [
        '@type'  => $entity->getEntityType()->getLabel(),
        '@label' => $entity->label(),
      ]);

      $this->processEntity($entity);
      $this->messenger->addMessage($message);
      return TRUE;
    }
    else {
      $message = $this->t('The @type "@label" couldn\'t be started.', [
        '@type'  => $entity->getEntityType()->getLabel(),
        '@label' => $entity->label(),
      ]);
      $this->messenger->addError($message);
      return FALSE;
    }
  }

  /**
   * Returns the message to show the user after an item was processed.
   *
   * @param int $count
   *   Count of processed translations.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The item processed message.
   */
  protected function getProcessedMessage($count) {
    $this->awsEc2Service->updateInstances();
    return $this->formatPlural($count, 'Started @count item.', 'Started @count items.');
  }

}

==> cloud-8.x-2.0-rc2.tar.gz: cloud/modules/cloud_service_providers/aws_cloud/src/Form/Ec2/InstanceStartMultipleForm.php <==
<?php

namespace Drupal\aws_cloud\Form\Ec2;

use Drupal\cloud\Entity\CloudContentEntityBase;

/**
 * Provides an entities start confirmation form.
 */
class InstanceStartMultipleForm extends AwsCloudProcessMultipleForm {

  /**
   * {@inheritdoc}
   */
  public function getQuestion() {

    return $this->formatPlural(count($this->selection),
      'Are you sure you want to start this @item?',
      'Are you sure you want to start these @items?', [
        '@item' => $this->entityType->getSingularLabel(),
        '@items' => $this->entityType->getPluralLabel(),
      ]
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getConfirmText() {

    return $this->t('Start');
  }

  /**
   * {@inheritdoc}
   */
  protected function processCloudResource(CloudContentEntityBase $entity) {

    $this->ec2Service->setCloudContext($entity->getCloudContext());

    return $this->ec2Service->startInstances([
      'InstanceIds' => [$entity->getInstanceId()],
    ]);
  }

  /**
   * {@inheritdoc}
   */
  protected function processEntity(CloudContentEntityBase $entity) {}

  /**
   * Process an entity and related AWS resource.
   *
   * @param \Drupal\cloud\Entity\CloudContentEntityBase $entity
   *   An entity object.
   *
   * @return bool
   *   Succeeded or failed.
   */
  protected function process(CloudContentEntityBase $entity) {

    if (!empty($entity) && $this->processCloudResource($entity)) {
      $message = $this->t('The @type "@label" has been processed.', [
        '@type'  => !empty($entity->getEntityType()) ? $entity->getEntityType()->getLabel() : 'N/A',
        '@label' => $entity->label(),
      ]);

      $this->processEntity($entity);
      $this->messenger->addMessage($message);
      return TRUE;
    }
    else {
      $message = $this->t('The @type "@label" couldn\'t be processed.', [
        '@type'  => !empty($entity->getEntityType()) ? $entity->getEntityType()->getLabel() : 'N/A',
        '@label' => $entity->label(),
      ]);
      $this->messenger->addError($message);
      return FALSE;
    }
  }

  /**
   * Returns the message to show the user after an item was processed.
   *
   * @param int $count
   *   Count of processed translations.
   *
   * @return \Drupal\Core\StringTranslation\TranslatableMarkup
   *   The item processed message.
   */
  protected function getProcessedMessage($count) {
    $this->ec2Service->updateInstances();
    return $this->formatPlural($count, 'Started @count item.', 'Started @count items.');
  }

}
